@@ -44,9 +44,9 @@ Example::
 
 __docformat__ = "restructuredtext en"
 
-import __builtin__
-if not hasattr(__builtin__, '_'):
-    __builtin__._ = str
+from logilab.common.compat import raw_input, builtins
+if not hasattr(builtins, '_'):
+    builtins._ = str
 
 
 def init_readline(complete_method, histfile=None):
@@ -92,8 +92,8 @@ class CLIHelper:
     and provide an help system.
     """
 
-    CMD_MAP = {'help' : _("Others"),
-               'quit' : _("Others"),
+    CMD_MAP = {'help': _("Others"),
+               'quit': _("Others"),
                }
     CMD_PREFIX = ''
 
@@ -105,7 +105,7 @@ class CLIHelper:
 
     def run(self):
         """loop on user input, exit on EOF"""
-        while 1:
+        while True:
             try:
                 line = raw_input('>>> ')
             except EOFError:
@@ -171,8 +171,7 @@ class CLIHelper:
         elif command is None or command not in self._topics:
             print _("Use help <topic> or help <command>.")
             print _("Available topics are:")
-            topics = self._topics.keys()
-            topics.sort()
+            topics = sorted(self._topics.keys())
             for topic in topics:
                 print '\t', topic
             print
