@@ -113,10 +113,13 @@ from ConfigParser import ConfigParser, NoOptionError, NoSectionError, \
      DuplicateSectionError
 from warnings import warn
 
-from logilab.common.compat import set, reversed
+from logilab.common.compat import callable, raw_input, str_encode as _encode
+
 from logilab.common.textutils import normalize_text, unquote
 from logilab.common import optik_ext as optparse
 
+OptionError = optparse.OptionError
+
 REQUIRED = []
 
 class UnsupportedAction(Exception):
@@ -130,11 +133,6 @@ def _get_encoding(encoding, stream):
         encoding = locale.getpreferredencoding()
     return encoding
 
-def _encode(string, encoding):
-    if isinstance(string, unicode):
-        return string.encode(encoding)
-    return str(string)
-
 
 # validation functions ########################################################
 
@@ -197,8 +195,8 @@ def bytes_validator(optdict, name, value):
     return optparse.check_bytes(None, name, value)
 
 
-VALIDATORS = {'string' : unquote,
-              'int' : int,
+VALIDATORS = {'string': unquote,
+              'int': int,
               'float': float,
               'file': file_validator,
               'font': unquote,
@@ -342,7 +340,7 @@ def format_option_value(optdict, value):
     if isinstance(value, (list, tuple)):
         value = ','.join(value)
     elif isinstance(value, dict):
-        value = ','.join(['%s:%s' % (k,v) for k,v in value.items()])
+        value = ','.join(['%s:%s' % (k, v) for k, v in value.items()])
     elif hasattr(value, 'match'): # optdict.get('type') == 'regexp'
         # compiled regexp
         value = value.pattern
@@ -362,6 +360,10 @@ def ini_format_section(stream, section, options, encoding=None, doc=None):
     if doc:
         print >> stream, _encode(comment(doc), encoding)
     print >> stream, '[%s]' % section
+    ini_format(stream, options, encoding)
+
+def ini_format(stream, options, encoding):
+    """format options using the INI format"""
     for optname, optdict, value in options:
         value = format_option_value(optdict, value)
         help = optdict.get('help')
@@ -397,7 +399,7 @@ def rest_format_section(stream, section, options, encoding=None, doc=None):
         if value:
             value = _encode(format_option_value(optdict, value), encoding)
             print >> stream, ''
-            print >> stream, '  Default: ``%s``' % value.replace("`` ","```` ``")
+            print >> stream, '  Default: ``%s``' % value.replace("`` ", "```` ``")
 
 
 class OptionsManagerMixIn(object):
@@ -479,7 +481,7 @@ class OptionsManagerMixIn(object):
         args, optdict = self.optik_option(provider, opt, optdict)
         option = optikcontainer.add_option(*args, **optdict)
         self._all_options[opt] = provider
-        self._maxlevel = max(self._maxlevel, option.level)
+        self._maxlevel = max(self._maxlevel, option.level or 0)
 
     def optik_option(self, provider, opt, optdict):
         """get our personal option definition and return a suitable form for
@@ -500,7 +502,7 @@ class OptionsManagerMixIn(object):
                 not optdict['action'] in ('store_true', 'store_false')):
                 optdict['help'] += ' [current: %default]'
             del optdict['default']
-        args = ['--' + opt]
+        args = ['--' + str(opt)]
         if 'short' in optdict:
             self._short_options[optdict['short']] = opt
             args.append('-' + optdict['short'])
@@ -812,13 +814,13 @@ class OptionsProviderMixIn(object):
             opt = self.option_name(opt, optdict)
             _list = getattr(self.config, opt, None)
             if _list is None:
-                if type(value) in (type(()), type([])):
+                if isinstance(value, (list, tuple)):
                     _list = value
                 elif value is not None:
                     _list = []
                     _list.append(value)
                 setattr(self.config, opt, _list)
-            elif type(_list) is type(()):
+            elif isinstance(_list, tuple):
                 setattr(self.config, opt, _list + (value,))
             else:
                 _list.append(value)
@@ -855,7 +857,8 @@ class OptionsProviderMixIn(object):
         for option in self.options:
             if option[0] == opt:
                 return option[1]
-        raise optparse.OptionError('no such option in section %r' % self.name, opt)
+        raise OptionError('no such option %s in section %r'
+                          % (opt, self.name), opt)
 
 
     def all_options(self):
@@ -940,7 +943,7 @@ class ConfigurationMixIn(OptionsManagerMixIn, OptionsProviderMixIn):
     def get(self, key, default=None):
         try:
             return getattr(self.config, self.option_name(key))
-        except (optparse.OptionError, AttributeError):
+        except (OptionError, AttributeError):
             return default
 
 
