@@ -1,19 +1,35 @@
-"""A few useful function/method decorators.
-
-:copyright: 2006-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
-"""
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
+""" A few useful function/method decorators. """
 __docformat__ = "restructuredtext en"
 
-from types import MethodType
+import types
 from time import clock, time
 import sys, re
 
 # XXX rewrite so we can use the decorator syntax when keyarg has to be specified
 
+def _is_generator_function(callableobj):
+    return callableobj.func_code.co_flags & 0x20
+
 def cached(callableobj, keyarg=None):
     """Simple decorator to cache result of method call."""
+    assert not _is_generator_function(callableobj), 'cannot cache generator function: %s' % callableobj
     if callableobj.func_code.co_argcount == 1 or keyarg == 0:
 
         def cache_wrapper1(self, *args):
@@ -26,7 +42,11 @@ def cached(callableobj, keyarg=None):
                 value = callableobj(self, *args)
                 setattr(self, cache, value)
                 return value
-        cache_wrapper1.__doc__ = callableobj.__doc__
+        try:
+            cache_wrapper1.__doc__ = callableobj.__doc__
+            cache_wrapper1.func_name = callableobj.func_name
+        except:
+            pass
         return cache_wrapper1
 
     elif keyarg:
@@ -47,7 +67,11 @@ def cached(callableobj, keyarg=None):
                 #print 'miss', self, cache, key
                 _cache[key] = callableobj(self, *args, **kwargs)
             return _cache[key]
-        cache_wrapper2.__doc__ = callableobj.__doc__
+        try:
+            cache_wrapper2.__doc__ = callableobj.__doc__
+            cache_wrapper2.func_name = callableobj.func_name
+        except:
+            pass
         return cache_wrapper2
 
     def cache_wrapper3(self, *args):
@@ -65,7 +89,11 @@ def cached(callableobj, keyarg=None):
             #print 'miss'
             _cache[args] = callableobj(self, *args)
         return _cache[args]
-    cache_wrapper3.__doc__ = callableobj.__doc__
+    try:
+        cache_wrapper3.__doc__ = callableobj.__doc__
+        cache_wrapper3.func_name = callableobj.func_name
+    except:
+        pass
     return cache_wrapper3
 
 def clear_cache(obj, funcname):
@@ -116,8 +144,8 @@ class iclassmethod(object):
         self.func = func
     def __get__(self, instance, objtype):
         if instance is None:
-            return MethodType(self.func, objtype, objtype.__class__)
-        return MethodType(self.func, instance, objtype)
+            return types.MethodType(self.func, objtype, objtype.__class__)
+        return types.MethodType(self.func, instance, objtype)
     def __set__(self, instance, value):
         raise AttributeError("can't set attribute")
 
