@@ -28,14 +28,16 @@ __docformat__ = "restructuredtext en"
 import sys
 import shutil
 import mimetypes
-from os.path import isabs, isdir, islink, split, exists, walk, normpath, join
+from os.path import isabs, isdir, islink, split, exists, normpath, join
 from os.path import abspath
-from os import sep, mkdir, remove, listdir, stat, chmod
+from os import sep, mkdir, remove, listdir, stat, chmod, walk
 from stat import ST_MODE, S_IWRITE
 from cStringIO import StringIO
 
 from logilab.common import STD_BLACKLIST as BASE_BLACKLIST, IGNORED_EXTENSIONS
 from logilab.common.shellutils import find
+from logilab.common.deprecation import deprecated
+from logilab.common.compat import FileIO, any
 
 def first_level_directory(path):
     """Return the first level directory of a path.
@@ -123,9 +125,10 @@ def ensure_fs_mode(filepath, desired_mode=S_IWRITE):
         chmod(filepath, mode | desired_mode)
 
 
-class ProtectedFile(file):
-    """A special file-object class that automatically that automatically
-    does a 'chmod +w' when needed.
+# XXX (syt) unused? kill?
+class ProtectedFile(FileIO):
+    """A special file-object class that automatically does a 'chmod +w' when
+    needed.
 
     XXX: for now, the way it is done allows 'normal file-objects' to be
     created during the ProtectedFile object lifetime.
@@ -150,7 +153,7 @@ class ProtectedFile(file):
             if not self.original_mode & S_IWRITE:
                 chmod(filepath, self.original_mode | S_IWRITE)
                 self.mode_changed = True
-        file.__init__(self, filepath, mode)
+        FileIO.__init__(self, filepath, mode)
 
     def _restore_mode(self):
         """restores the original mode if needed"""
@@ -162,7 +165,7 @@ class ProtectedFile(file):
     def close(self):
         """restore mode before closing"""
         self._restore_mode()
-        file.close(self)
+        FileIO.close(self)
 
     def __del__(self):
         if not self.closed:
@@ -241,11 +244,6 @@ def relative_path(from_file, to_file):
     return sep.join(result)
 
 
-from logilab.common.textutils import _LINE_RGX
-from sys import version_info
-_HAS_UNIV_OPEN = version_info[:2] >= (2, 3)
-del version_info
-
 def norm_read(path):
     """Return the content of the file with normalized line feeds.
 
@@ -255,10 +253,8 @@ def norm_read(path):
     :rtype: str
     :return: the content of the file with normalized line feeds
     """
-    if _HAS_UNIV_OPEN:
-        return open(path, 'U').read()
-    return _LINE_RGX.sub('\n', open(path).read())
-
+    return open(path, 'U').read()
+norm_read = deprecated("use \"open(path, 'U').read()\"")(norm_read)
 
 def norm_open(path):
     """Return a stream for a file with content with normalized line feeds.
@@ -269,10 +265,8 @@ def norm_open(path):
     :rtype: file or StringIO
     :return: the opened file with normalized line feeds
     """
-    if _HAS_UNIV_OPEN:
-        return open(path, 'U')
-    return StringIO(_LINE_RGX.sub('\n', open(path).read()))
-
+    return open(path, 'U')
+norm_open = deprecated("use \"open(path, 'U')\"")(norm_open)
 
 def lines(path, comments=None):
     """Return a list of non empty lines in the file located at `path`.
@@ -292,7 +286,7 @@ def lines(path, comments=None):
 
     :warning: at some point this function will probably return an iterator
     """
-    stream = norm_open(path)
+    stream = open(path, 'U')
     result = stream_lines(stream, comments)
     stream.close()
     return result
@@ -356,35 +350,35 @@ def export(from_dir, to_dir,
       flag indicating whether information about exported files should be
       printed to stderr, default to False
     """
-    def make_mirror(_, directory, fnames):
-        """walk handler"""
-        for norecurs in blacklist:
-            try:
-                fnames.remove(norecurs)
-            except ValueError:
-                continue
-        for filename in fnames:
-            # don't include binary files
-            for ext in ignore_ext:
-                if filename.endswith(ext):
-                    break
-            else:
-                src = join(directory, filename)
-                dest = to_dir + src[len(from_dir):]
-                if verbose:
-                    print >> sys.stderr, src, '->', dest
-                if isdir(src):
-                    if not exists(dest):
-                        mkdir(dest)
-                else:
-                    if exists(dest):
-                        remove(dest)
-                    shutil.copy2(src, dest)
     try:
         mkdir(to_dir)
     except OSError:
-        pass
-    walk(from_dir, make_mirror, None)
+        pass # FIXME we should use "exists" if the point is about existing dir
+             # else (permission problems?) shouldn't return / raise ?
+    for directory, dirnames, filenames in walk(from_dir):
+        for norecurs in blacklist:
+            try:
+                dirnames.remove(norecurs)
+            except ValueError:
+                continue
+        for dirname in dirnames:
+            src = join(directory, dirname)
+            dest = to_dir + src[len(from_dir):]
+            if isdir(src):
+                if not exists(dest):
+                    mkdir(dest)
+        for filename in filenames:
+            # don't include binary files
+            # endswith does not accept tuple in 2.4
+            if any([filename.endswith(ext) for ext in ignore_ext]):
+                continue
+            src = join(directory, filename)
+            dest = to_dir + src[len(from_dir):]
+            if verbose:
+                print >> sys.stderr, src, '->', dest
+            if exists(dest):
+                remove(dest)
+            shutil.copy2(src, dest)
 
 
 def remove_dead_links(directory, verbose=0):
@@ -398,12 +392,11 @@ def remove_dead_links(directory, verbose=0):
       flag indicating whether information about deleted links should be
       printed to stderr, default to False
     """
-    def _remove_dead_link(_, directory, fnames):
-        """walk handler"""
-        for filename in fnames:
-            src = join(directory, filename)
+    for dirpath, dirname, filenames in walk(directory):
+        for filename in dirnames + filenames:
+            src = join(dirpath, filename)
             if islink(src) and not exists(src):
                 if verbose:
                     print 'remove dead link', src
                 remove(src)
-    walk(directory, _remove_dead_link, None)
+
