@@ -28,14 +28,12 @@ Example:
 >>> return run(options, args[1:])
 
 With mymod.build that defines two functions run and add_options
-
-
-
-
 """
 __docformat__ = "restructuredtext en"
 
-# XXX merge with optik_ext ? merge with clcommands ?
+from warnings import warn
+warn('lgc.optparser module is deprecated, use lgc.clcommands instead', DeprecationWarning,
+     stacklevel=2)
 
 import sys
 import optparse
@@ -48,11 +46,11 @@ class OptionParser(optparse.OptionParser):
         self.min_args, self.max_args = 0, 1
 
     def add_command(self, name, mod_or_funcs, help=''):
-        """name of the command
-	name of module or tuple of functions (run, add_options)
-	"""
+        """name of the command, name of module or tuple of functions
+        (run, add_options)
+        """
         assert isinstance(mod_or_funcs, str) or isinstance(mod_or_funcs, tuple), \
-	       "mod_or_funcs has to be a module name or a tuple of functions"
+            "mod_or_funcs has to be a module name or a tuple of functions"
         self._commands[name] = (mod_or_funcs, help)
 
     def print_main_help(self):
@@ -66,7 +64,7 @@ class OptionParser(optparse.OptionParser):
             self.print_main_help()
             sys.exit(1)
         cmd = args[0]
-	args = args[1:]
+        args = args[1:]
         if cmd not in self._commands:
             if cmd in ('-h', '--help'):
                 self.print_main_help()
@@ -81,8 +79,8 @@ class OptionParser(optparse.OptionParser):
         self.description = help
         if isinstance(mod_or_f, str):
             exec 'from %s import run, add_options' % mod_or_f
-	else:
-	    run, add_options = mod_or_f
+        else:
+            run, add_options = mod_or_f
         add_options(self)
         (options, args) = self.parse_args(args)
         if not (self.min_args <= len(args) <= self.max_args):
