@@ -29,9 +29,12 @@ import tempfile
 import time
 import fnmatch
 import errno
-from os.path import exists, isdir, islink, basename, join, walk
+from os.path import exists, isdir, islink, basename, join
+
+from logilab.common import STD_BLACKLIST, _handle_blacklist
+from logilab.common.compat import raw_input
+from logilab.common.compat import str_to_bytes
 
-from logilab.common import STD_BLACKLIST
 try:
     from logilab.common.proc import ProcInfo, NoSuchProcess
 except ImportError:
@@ -168,22 +171,14 @@ def find(directory, exts, exclude=False, blacklist=STD_BLACKLIST):
                 if filename.endswith(ext):
                     return True
             return False
-    def func(files, directory, fnames):
-        """walk handler"""
-        # remove files/directories in the black list
-        for norecurs in blacklist:
-            try:
-                fnames.remove(norecurs)
-            except ValueError:
-                continue
-        for filename in fnames:
-            src = join(directory, filename)
-            if isdir(src):
-                continue
-            if match(filename, exts):
-                files.append(src)
     files = []
-    walk(directory, func, files)
+    for dirpath, dirnames, filenames in os.walk(directory):
+        _handle_blacklist(blacklist, dirnames, filenames)
+        # don't append files if the directory is blacklisted
+        dirname = basename(dirpath)
+        if dirname in blacklist:
+            continue
+        files.extend([join(dirpath, f) for f in filenames if match(f, exts)])
     return files
 
 
@@ -210,11 +205,9 @@ def globfind(directory, pattern, blacklist=STD_BLACKLIST):
       iterator over the list of all matching files
     """
     for curdir, dirnames, filenames in os.walk(directory):
+        _handle_blacklist(blacklist, dirnames, filenames)
         for fname in fnmatch.filter(filenames, pattern):
             yield join(curdir, fname)
-        for skipped in blacklist:
-            if skipped in dirnames:
-                dirnames.remove(skipped)
 
 def unzip(archive, destdir):
     import zipfile
@@ -239,8 +232,8 @@ class Execute:
         errfile = tempfile.mktemp()
         self.status = os.system("( %s ) >%s 2>%s" %
                                 (command, outfile, errfile)) >> 8
-        self.out = open(outfile,"r").read()
-        self.err = open(errfile,"r").read()
+        self.out = open(outfile, "r").read()
+        self.err = open(errfile, "r").read()
         os.remove(outfile)
         os.remove(errfile)
 
@@ -255,7 +248,7 @@ def acquire_lock(lock_file, max_try=10, delay=10, max_delay=3600):
     while count:
         try:
             fd = os.open(lock_file, os.O_EXCL | os.O_RDWR | os.O_CREAT)
-            os.write(fd, str(os.getpid()))
+            os.write(fd, str_to_bytes(str(os.getpid())) )
             os.close(fd)
             return True
         except OSError, e:
@@ -311,8 +304,9 @@ class ProgressBar(object):
         return self._current_text
 
     def _set_text(self, text=None):
-        self._current_text = text
-        self.refresh()
+        if text != self._current_text:
+            self._current_text = text
+            self.refresh()
 
     def _del_text(self):
         self.text = None
@@ -339,6 +333,46 @@ class ProgressBar(object):
             self._last_text_write_size = len(text.rstrip())
         self._stream.flush()
 
+    def finish(self):
+        self._stream.write('\n')
+        self._stream.flush()
+
+
+class DummyProgressBar(object):
+    __slot__ = ('text',)
+
+    def refresh(self):
+        pass
+    def update(self):
+        pass
+    def finish(self):
+        pass
+
+
+_MARKER = object()
+class progress(object):
+
+    def __init__(self, nbops=_MARKER, size=_MARKER, stream=_MARKER, title=_MARKER, enabled=True):
+        self.nbops = nbops
+        self.size = size
+        self.stream = stream
+        self.title = title
+        self.enabled = enabled
+
+    def __enter__(self):
+        if self.enabled:
+            kwargs = {}
+            for attr in ('nbops', 'size', 'stream', 'title'):
+                value = getattr(self, attr)
+                if value is not _MARKER:
+                    kwargs[attr] = value
+            self.pb = ProgressBar(**kwargs)
+        else:
+            self.pb =  DummyProgressBar()
+        return self.pb
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.pb.finish()
 
 class RawInput(object):
 
@@ -382,7 +416,7 @@ class RawInput(object):
 
     def confirm(self, question, default_is_yes=True):
         default = default_is_yes and 'y' or 'n'
-        answer = self.ask(question, ('y','n'), default)
+        answer = self.ask(question, ('y', 'n'), default)
         return answer == 'y'
 
 ASK = RawInput()
