@@ -15,12 +15,8 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
-"""Prioritized tasks queue
+"""Prioritized tasks queue"""
 
-:organization: Logilab
-
-
-"""
 __docformat__ = "restructuredtext en"
 
 from bisect import insort_left
@@ -30,11 +26,13 @@ LOW = 0
 MEDIUM = 10
 HIGH = 100
 
-REVERSE_PRIORITY = {
-    0: 'LOW',
-    10: 'MEDIUM',
-    100: 'HIGH'
+PRIORITY = {
+    'LOW': LOW,
+    'MEDIUM': MEDIUM,
+    'HIGH': HIGH,
     }
+REVERSE_PRIORITY = dict((values, key) for key, values in PRIORITY.iteritems())
+
 
 
 class PrioritizedTasksQueue(Queue):
@@ -90,6 +88,9 @@ class Task(object):
     def __cmp__(self, other):
         return cmp(self.priority, other.priority)
 
+    def __lt__(self, other):
+        return self.priority < other.priority
+
     def __eq__(self, other):
         return self.id == other.id
 
