@@ -17,6 +17,8 @@
 # with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 import tempfile
 import os
+from os.path import join, dirname, abspath
+
 from cStringIO import StringIO
 from sys import version_info
 
@@ -25,9 +27,11 @@ from logilab.common.optik_ext import OptionValueError
 from logilab.common.configuration import Configuration, \
      OptionsManagerMixIn, OptionsProviderMixIn, Method, read_old_config
 
+DATA = join(dirname(abspath(__file__)), 'data')
+
 options = [('dothis', {'type':'yn', 'action': 'store', 'default': True, 'metavar': '<y or n>'}),
            ('value', {'type': 'string', 'metavar': '<string>', 'short': 'v'}),
-           ('multiple', {'type': 'csv', 'default': ('yop','yep'),
+           ('multiple', {'type': 'csv', 'default': ('yop', 'yep'),
                          'metavar': '<comma separated values>',
                          'help': 'you can also document the option'}),
            ('number', {'type': 'int', 'default':2, 'metavar':'<int>', 'help': 'boom'}),
@@ -58,7 +62,7 @@ class ConfigurationTC(TestCase):
         cfg = self.cfg
         self.assertEqual(cfg['dothis'], True)
         self.assertEqual(cfg['value'], None)
-        self.assertEqual(cfg['multiple'], ('yop','yep'))
+        self.assertEqual(cfg['multiple'], ('yop', 'yep'))
         self.assertEqual(cfg['number'], 2)
         self.assertEqual(cfg['choice'], 'yo')
         self.assertEqual(cfg['multiple-choice'], ('yo', 'ye'))
@@ -138,7 +142,7 @@ diffgroup=zou
             self.cfg.load_file_configuration(file)
             self.assertEqual(self.cfg['dothis'], False)
             self.assertEqual(self.cfg['value'], None)
-            self.assertEqual(self.cfg['multiple'], ['yop','yepii'])
+            self.assertEqual(self.cfg['multiple'], ['yop', 'yepii'])
             self.assertEqual(self.cfg['diffgroup'], 'zou')
         finally:
             os.remove(file)
@@ -278,7 +282,7 @@ options:
         changes = [('renamed', 'renamed', 'choice'),
                    ('moved', 'named', 'old', 'test'),
                    ]
-        read_old_config(self.cfg, changes, 'data/test.ini')
+        read_old_config(self.cfg, changes, join(DATA, 'test.ini'))
         stream = StringIO()
         self.cfg.generate_config(stream)
         self.assertMultiLineEqual(stream.getvalue().strip(), """[TEST]
