@@ -1,3 +1,20 @@
+# copyright 2003-2010 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# contact http://www.logilab.fr/ -- mailto:contact@logilab.fr
+#
+# This file is part of logilab-common.
+#
+# logilab-common is free software: you can redistribute it and/or modify it under
+# the terms of the GNU Lesser General Public License as published by the Free
+# Software Foundation, either version 2.1 of the License, or (at your option) any
+# later version.
+#
+# logilab-common is distributed in the hope that it will be useful, but WITHOUT
+# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
+# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
+# details.
+#
+# You should have received a copy of the GNU Lesser General Public License along
+# with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """Functions to generate files readable with Georg Sander's vcg
 (Visualization of Compiler Graphs).
 
@@ -7,9 +24,9 @@ Note that vcg exists as a debian package.
 See vcg's documentation for explanation about the different values that
 maybe used for the functions parameters.
 
-:copyright: 2000-2008 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
-:contact: http://www.logilab.fr/ -- mailto:contact@logilab.fr
-:license: GNU Lesser General Public License, v2.1 - http://www.gnu.org/licenses
+
+
+
 """
 __docformat__ = "restructuredtext en"
 
@@ -17,11 +34,11 @@ import string
 
 ATTRS_VAL = {
     'algos':       ('dfs', 'tree', 'minbackward',
-                    'left_to_right','right_to_left',
-                    'top_to_bottom','bottom_to_top',
+                    'left_to_right', 'right_to_left',
+                    'top_to_bottom', 'bottom_to_top',
                     'maxdepth', 'maxdepthslow', 'mindepth', 'mindepthslow',
                     'mindegree', 'minindegree', 'minoutdegree',
-                    'maxdegree','maxindegree', 'maxoutdegree'),
+                    'maxdegree', 'maxindegree', 'maxoutdegree'),
     'booleans':    ('yes', 'no'),
     'colors':      ('black', 'white', 'blue', 'red', 'green', 'yellow',
                     'magenta', 'lightgrey',
@@ -42,8 +59,8 @@ ATTRS_VAL = {
 #   1    -> int
 #   list -> value in list
 GRAPH_ATTRS = {
-    'title' :              0,
-    'label' :              0,
+    'title':              0,
+    'label':              0,
     'color':               ATTRS_VAL['colors'],
     'textcolor':           ATTRS_VAL['colors'],
     'bordercolor':         ATTRS_VAL['colors'],
@@ -59,10 +76,10 @@ GRAPH_ATTRS = {
     'horizontal_order':    1,
     'xspace':              1,
     'yspace':              1,
-    'layoutalgorithm' :    ATTRS_VAL['algos'],
-    'late_edge_labels' :   ATTRS_VAL['booleans'],
+    'layoutalgorithm':    ATTRS_VAL['algos'],
+    'late_edge_labels':   ATTRS_VAL['booleans'],
     'display_edge_labels': ATTRS_VAL['booleans'],
-    'dirty_edge_labels' :  ATTRS_VAL['booleans'],
+    'dirty_edge_labels':  ATTRS_VAL['booleans'],
     'finetuning':          ATTRS_VAL['booleans'],
     'manhattan_edges':     ATTRS_VAL['booleans'],
     'smanhattan_edges':    ATTRS_VAL['booleans'],
@@ -72,8 +89,8 @@ GRAPH_ATTRS = {
     'splines':             ATTRS_VAL['booleans'],
     }
 NODE_ATTRS = {
-    'title' :              0,
-    'label' :              0,
+    'title':              0,
+    'label':              0,
     'color':               ATTRS_VAL['colors'],
     'textcolor':           ATTRS_VAL['colors'],
     'bordercolor':         ATTRS_VAL['colors'],
@@ -88,12 +105,12 @@ NODE_ATTRS = {
     'horizontal_order':    1,
     }
 EDGE_ATTRS = {
-    'sourcename' :         0,
-    'targetname' :         0,
-    'label' :              0,
-    'linestyle' :          ATTRS_VAL['linestyles'],
-    'class' :              1,
-    'thickness' :          0,
+    'sourcename':         0,
+    'targetname':         0,
+    'label':              0,
+    'linestyle':          ATTRS_VAL['linestyles'],
+    'class':              1,
+    'thickness':          0,
     'color':               ATTRS_VAL['colors'],
     'textcolor':           ATTRS_VAL['colors'],
     'arrowcolor':          ATTRS_VAL['colors'],
